#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-8IHzdJkHQTmGwOvlkcDWHu
key:                  enclosed-exceptions-1.0.3-8IHzdJkHQTmGwOvlkcDWHu
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  81ad4be04fb97c89ae0b397452a506ba
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.6.6/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/enclosed-exceptions-1.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-8IHzdJkHQTmGwOvlkcDWHu
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    lifted-base-0.2.3.12-t6zvs0m7o6IP4mH5tvmLv
    monad-control-1.0.3.1-E5lxYdZ2T24L5KA6ZxZqUG transformers-0.6.1.0
    transformers-base-0.4.6.1-KXWNPb7DK3u8Vr2fZyR0eL

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

